@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2007, 2008, 2009, 2012, 2014, 2015, 2016, 2018 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2007-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "board.h"
 
@@ -28,46 +15,47 @@
 #include <QMainWindow>
 #include <QMessageBox>
 #include <QPainter>
+#include <QRandomGenerator>
 #include <QSettings>
 #include <QStatusBar>
 #include <QTimeLine>
+#include <QTime>
 #include <QTimer>
 
 #include <algorithm>
-#include <ctime>
 #include <random>
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 Board::Board(QMainWindow* parent)
-:	QWidget(parent),
-	m_done(false),
-	m_paused(false),
-	m_total_targets(3),
-	m_maze(0),
-	m_solver(0),
-	m_show_path(true),
-	m_smooth_movement(true),
-	m_col_delta(0),
-	m_row_delta(0),
-	m_unit(32),
-	m_zoom(5),
-	m_max_zoom(5),
-	m_zoom_size(14),
-	m_player_angle(360),
-	m_player_steps(0),
-	m_player_total_time(0),
-	m_hint(-1, -1),
-	m_hint_angle(0)
+	: QWidget(parent)
+	, m_done(false)
+	, m_paused(false)
+	, m_total_targets(3)
+	, m_maze(nullptr)
+	, m_solver(nullptr)
+	, m_show_path(true)
+	, m_smooth_movement(true)
+	, m_col_delta(0)
+	, m_row_delta(0)
+	, m_unit(32)
+	, m_zoom(5)
+	, m_max_zoom(5)
+	, m_zoom_size(14)
+	, m_player_angle(360)
+	, m_player_steps(0)
+	, m_player_total_time(0)
+	, m_hint(-1, -1)
+	, m_hint_angle(0)
 {
 	setMinimumSize(448, 448);
 	setFocusPolicy(Qt::StrongFocus);
 
 	m_move_animation = new QTimeLine(60, this);
 	m_move_animation->setFrameRange(0, 3);
-	m_move_animation->setCurveShape(QTimeLine::LinearCurve);
+	m_move_animation->setEasingCurve(QEasingCurve::Linear);
 	m_move_animation->setUpdateInterval(15);
-	connect(m_move_animation, &QTimeLine::frameChanged, this, static_cast<void (Board::*)()>(&Board::repaint));
+	connect(m_move_animation, &QTimeLine::frameChanged, this, qOverload<>(&Board::repaint));
 
 	// Create status messages
 	m_status_time_message = new QLabel;
@@ -101,7 +89,7 @@ Board::Board(QMainWindow* parent)
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 Board::~Board()
 {
@@ -110,7 +98,7 @@ Board::~Board()
 	delete m_theme;
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::newGame()
 {
@@ -118,14 +106,7 @@ void Board::newGame()
 	m_status_timer->stop();
 
 	// Fetch new seed
-#ifndef Q_OS_WIN
-	std::random_device rd;
-	unsigned int seed = rd();
-#else
-	std::mt19937 gen(time(0));
-	std::uniform_int_distribution<unsigned int> dist;
-	unsigned int seed = dist(gen);
-#endif
+	const unsigned int seed = QRandomGenerator::global()->generate();
 
 	// Set values for new game
 	QSettings settings;
@@ -159,7 +140,7 @@ void Board::newGame()
 	emit pauseChecked(false);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::loadGame()
 {
@@ -214,7 +195,7 @@ void Board::loadGame()
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::saveGame()
 {
@@ -232,7 +213,7 @@ void Board::saveGame()
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::pauseGame(bool paused)
 {
@@ -249,7 +230,7 @@ void Board::pauseGame(bool paused)
 	emit hintAvailable(!m_paused);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::hint()
 {
@@ -272,7 +253,7 @@ void Board::hint()
 	update();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::zoomIn()
 {
@@ -283,7 +264,7 @@ void Board::zoomIn()
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::zoomOut()
 {
@@ -294,7 +275,7 @@ void Board::zoomOut()
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::loadSettings()
 {
@@ -330,7 +311,15 @@ void Board::loadSettings()
 	updateStatusMessage();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
+
+void Board::focusOutEvent(QFocusEvent* event)
+{
+	emit pauseChecked(true);
+	QWidget::focusOutEvent(event);
+}
+
+//-----------------------------------------------------------------------------
 
 void Board::keyPressEvent(QKeyEvent* event)
 {
@@ -423,7 +412,17 @@ void Board::keyPressEvent(QKeyEvent* event)
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
+
+void Board::mousePressEvent(QMouseEvent* event)
+{
+	if (m_paused) {
+		emit pauseChecked(false);
+	}
+	QWidget::mousePressEvent(event);
+}
+
+//-----------------------------------------------------------------------------
 
 void Board::paintEvent(QPaintEvent*)
 {
@@ -438,14 +437,14 @@ void Board::paintEvent(QPaintEvent*)
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::resizeEvent(QResizeEvent*)
 {
 	scale();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::updateStatusMessage()
 {
@@ -459,7 +458,7 @@ void Board::updateStatusMessage()
 	m_status_remain_message->setText(tr("%1 of %2 targets remain") .arg(m_targets.size()) .arg(m_total_targets));
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::scale()
 {
@@ -472,7 +471,7 @@ void Board::scale()
 	QSettings().setValue("Zoom", m_zoom);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::generate(unsigned int seed)
 {
@@ -539,7 +538,7 @@ void Board::generate(unsigned int seed)
 	m_hint = QPoint(-1, -1);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::finish()
 {
@@ -565,10 +564,10 @@ void Board::finish()
 	update();
 
 	// Add high score
-	emit finished(m_player_steps, seconds, algorithm, size);
+	emit finished(seconds, m_player_steps, algorithm, size);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::renderBackground()
 {
@@ -580,7 +579,7 @@ void Board::renderBackground()
 	m_theme->drawBackground(painter);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::renderMaze()
 {
@@ -707,7 +706,7 @@ void Board::renderMaze()
 	}
 
 	// Draw targets
-	for (const QPoint& target : m_targets) {
+	for (const QPoint& target : qAsConst(m_targets)) {
 		if (view.contains(target)) {
 			m_theme->draw(painter, target.x() - column, target.y() - row, Theme::Target);
 		}
@@ -742,7 +741,7 @@ void Board::renderMaze()
 	m_theme->draw(painter, pos, pos, Theme::Player, m_player_angle);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::renderDone()
 {
@@ -792,7 +791,7 @@ void Board::renderDone()
 	renderText(&painter, tr("Success"));
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::renderPause()
 {
@@ -809,7 +808,7 @@ void Board::renderPause()
 	renderText(&painter, tr("Paused"));
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Board::renderText(QPainter* painter, const QString& message) const
 {
@@ -838,4 +837,4 @@ void Board::renderText(QPainter* painter, const QString& message) const
 	painter->restore();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
