@@ -1,29 +1,19 @@
-/***********************************************************************
- *
- * Copyright (C) 2007, 2008, 2012, 2014, 2015, 2018, 2019 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2007-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "locale_dialog.h"
+#include "scores_dialog.h"
 #include "window.h"
 
 #include <QApplication>
+#include <QCommandLineParser>
 
 int main(int argc, char** argv)
 {
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
 #if !defined(Q_OS_MAC)
 	if (!qEnvironmentVariableIsSet("QT_DEVICE_PIXEL_RATIO")
 			&& !qEnvironmentVariableIsSet("QT_AUTO_SCREEN_SCALE_FACTOR")
@@ -31,6 +21,8 @@ int main(int argc, char** argv)
 			&& !qEnvironmentVariableIsSet("QT_SCREEN_SCALE_FACTORS")) {
 		QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 	}
+#endif
+	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
 	QApplication app(argc, argv);
 	app.setApplicationName("CuteMaze");
@@ -42,10 +34,17 @@ int main(int argc, char** argv)
 	app.setWindowIcon(QIcon::fromTheme("cutemaze", QIcon(":/cutemaze.png")));
 	app.setDesktopFileName("cutemaze");
 #endif
-	app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
 	LocaleDialog::loadTranslator("cutemaze_");
 
+	ScoresDialog::migrate();
+
+	QCommandLineParser parser;
+	parser.setApplicationDescription(Window::tr("A top-down maze game"));
+	parser.addHelpOption();
+	parser.addVersionOption();
+	parser.process(app);
+
 	Window window;
 	window.show();
 	return app.exec();
