@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2007, 2008, 2009, 2012, 2014, 2015 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2007-2020 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "settings.h"
 
@@ -39,62 +26,61 @@
 #include <QVBoxLayout>
 
 namespace {
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 QString homeDataPath()
 {
-	return QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+	return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 // ControlButton class
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 class ControlButton : public QPushButton
 {
 public:
-	ControlButton(const QString& type, Qt::Key default_key_value, QWidget* parent = 0);
+	ControlButton(const QString& type, Qt::Key default_key_value, QWidget* parent = nullptr);
 
 	unsigned int key;
 	unsigned int default_key;
 
 protected:
-	virtual void hideEvent(QHideEvent* event);
-	virtual void keyPressEvent(QKeyEvent* event);
-	virtual void mousePressEvent(QMouseEvent* event);
+	void hideEvent(QHideEvent* event) override;
+	void keyPressEvent(QKeyEvent* event) override;
+	void mousePressEvent(QMouseEvent* event) override;
 };
 
 QList<ControlButton*> controls;
-ControlButton* active_control = 0;
+ControlButton* active_control = nullptr;
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 ControlButton::ControlButton(const QString& type, Qt::Key default_key_value, QWidget* parent)
-:	QPushButton(parent),
-	key(default_key_value),
-	default_key(default_key_value)
+	: QPushButton(parent)
+	, key(default_key_value)
+	, default_key(default_key_value)
 {
 	setObjectName("control_" + type);
 	setText(QKeySequence(key).toString());
 	setCheckable(true);
 	setAutoDefault(false);
 	setFocusPolicy(Qt::StrongFocus);
-	installEventFilter(this);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void ControlButton::hideEvent(QHideEvent* event)
 {
 	if (this == active_control) {
-		active_control = 0;
+		active_control = nullptr;
 		setChecked(false);
 	}
 	QPushButton::hideEvent(event);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void ControlButton::keyPressEvent(QKeyEvent* event)
 {
@@ -138,7 +124,7 @@ void ControlButton::keyPressEvent(QKeyEvent* event)
 			control = QKeySequence(key).toString(QKeySequence::NativeText);
 			break;
 		};
-		for (ControlButton* button : controls) {
+		for (ControlButton* button : qAsConst(controls)) {
 			if (button->text() == control) {
 				button->setText("");
 				button->key = 0;
@@ -146,13 +132,13 @@ void ControlButton::keyPressEvent(QKeyEvent* event)
 		}
 		setText(control);
 		setChecked(false);
-		active_control = 0;
+		active_control = nullptr;
 	} else {
 		QPushButton::keyPressEvent(event);
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void ControlButton::mousePressEvent(QMouseEvent* event)
 {
@@ -162,19 +148,19 @@ void ControlButton::mousePressEvent(QMouseEvent* event)
 		}
 		active_control = this;
 	} else {
-		active_control = 0;
+		active_control = nullptr;
 	}
 	QPushButton::mousePressEvent(event);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 }
 
 // Settings class
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 Settings::Settings(QWidget* parent)
-:	QDialog(parent)
+	: QDialog(parent)
 {
 	setWindowTitle(tr("Settings"));
 	m_theme = new Theme;
@@ -258,7 +244,7 @@ Settings::Settings(QWidget* parent)
 	loadSettings();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 Settings::~Settings()
 {
@@ -266,7 +252,7 @@ Settings::~Settings()
 	delete m_theme;
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Settings::accept()
 {
@@ -279,7 +265,7 @@ void Settings::accept()
 	settings.setValue("Smooth Movement", m_gameplay_smooth->isChecked());
 
 	// Write control button settings to disk
-	for (ControlButton* button : controls) {
+	for (ControlButton* button : qAsConst(controls)) {
 		settings.setValue("Controls/" + button->objectName().mid(8), button->key);
 	}
 
@@ -291,18 +277,18 @@ void Settings::accept()
 	QDialog::accept();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Settings::themeSelected(const QString& theme)
 {
 	if (!theme.isEmpty()) {
 		m_theme->load(theme);
 		generatePreview();
-		m_themes_remove_button->setEnabled(QFileInfo(homeDataPath() + '/' + theme + ".svg").exists());
+		m_themes_remove_button->setEnabled(QFileInfo::exists(homeDataPath() + '/' + theme + ".svg"));
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Settings::addTheme()
 {
@@ -314,7 +300,7 @@ void Settings::addTheme()
 
 	// Create data folder if necessary
 	QString dirpath = homeDataPath();
-	if (!QFileInfo(dirpath).exists()) {
+	if (!QFileInfo::exists(dirpath)) {
 		QDir dir = QDir::home();
 		if (!dir.mkpath(dirpath)) {
 			QMessageBox::warning(this, tr("Sorry"), tr("Unable to create data folder."));
@@ -340,7 +326,7 @@ void Settings::addTheme()
 	m_themes_selector->setCurrentIndex(theme);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Settings::removeTheme()
 {
@@ -350,7 +336,7 @@ void Settings::removeTheme()
 	}
 	QString dirpath = homeDataPath();
 	QString file = m_themes_selector->currentText() + ".svg";
-	if (!QFileInfo(dirpath + '/' + file).exists()) {
+	if (!QFileInfo::exists(dirpath + '/' + file)) {
 		return;
 	}
 
@@ -374,7 +360,7 @@ void Settings::removeTheme()
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Settings::loadSettings()
 {
@@ -387,7 +373,7 @@ void Settings::loadSettings()
 	m_gameplay_smooth->setChecked(settings.value("Smooth Movement", true).toBool());
 
 	// Read control button settings from disk
-	for (ControlButton* button : controls) {
+	for (ControlButton* button : qAsConst(controls)) {
 		button->key = settings.value("Controls/" + button->objectName().mid(8), button->default_key).toUInt();
 		button->setText(QKeySequence(button->key).toString());
 	}
@@ -403,7 +389,7 @@ void Settings::loadSettings()
 	m_themes_selector->setCurrentIndex(theme);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Settings::generatePreview()
 {
@@ -449,4 +435,4 @@ void Settings::generatePreview()
 	m_themes_preview->setPixmap(pixmap);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
