@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2007, 2008, 2009, 2012, 2014, 2015, 2019 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2007-2020 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "theme.h"
 
@@ -30,7 +17,7 @@
 #include <QSvgRenderer>
 
 namespace {
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 struct CornerType
 {
@@ -55,41 +42,41 @@ CornerType corners[15] = {
 	{0, 0}
 };
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
-Theme::Theme() :
-	m_unit(32),
-	m_ratio(1)
+Theme::Theme()
+	: m_unit(32)
+	, m_ratio(1)
 {
 	m_renderer = new QSvgRenderer;
 
 	// Load theme locations
 #if defined(Q_OS_MAC)
-	m_locations = QStandardPaths::standardLocations(QStandardPaths::DataLocation);
+	m_locations = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
 #elif defined(Q_OS_UNIX)
 	m_locations = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
 	for (int i = 0; i < m_locations.size(); ++i) {
 		m_locations[i] += "/games/cutemaze";
 	}
-	m_locations.prepend(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+	m_locations.prepend(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
 #elif defined(Q_OS_WIN)
-	m_locations = QStandardPaths::standardLocations(QStandardPaths::DataLocation);
+	m_locations = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
 	m_locations.append(QCoreApplication::applicationDirPath() + "/Themes");
 #endif
 	m_locations.append(":/games/cutemaze");
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 Theme::~Theme()
 {
 	delete m_renderer;
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 QStringList Theme::available() const
 {
@@ -121,14 +108,14 @@ QStringList Theme::available() const
 	return list;
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::load(const QString& name)
 {
 	QString theme = name;
 
 	QFileInfo info;
-	for (const QString& location : m_locations) {
+	for (const QString& location : qAsConst(m_locations)) {
 		info.setFile(location + '/' + name + ".svg");
 		if (info.exists()) {
 			theme = info.canonicalFilePath();
@@ -140,7 +127,7 @@ void Theme::load(const QString& name)
 	scale(m_unit);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::scale(int unit)
 {
@@ -170,7 +157,7 @@ void Theme::scale(int unit)
 	cache("background", m_pixmap[Background], bounds);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::setDevicePixelRatio(int ratio)
 {
@@ -178,7 +165,7 @@ void Theme::setDevicePixelRatio(int ratio)
 	scale(m_unit);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::draw(QPainter& painter, int column, int row, enum Element element) const
 {
@@ -186,7 +173,7 @@ void Theme::draw(QPainter& painter, int column, int row, enum Element element) c
 	painter.drawPixmap(column * 3 * m_unit, row * 3 * m_unit, m_pixmap[element]);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::draw(QPainter& painter, int column, int row, enum RotatedElement element, int angle) const
 {
@@ -199,14 +186,14 @@ void Theme::draw(QPainter& painter, int column, int row, enum RotatedElement ele
 	painter.drawPixmap(column * 3 * m_unit, row * 3 * m_unit, m_pixmap_rotated[element][angle]);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::drawBackground(QPainter& painter) const
 {
 	painter.fillRect(0, 0, painter.device()->width(), painter.device()->height(), m_pixmap[Background]);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::drawCorner(QPainter& painter, int column, int row, unsigned char walls) const
 {
@@ -215,7 +202,7 @@ void Theme::drawCorner(QPainter& painter, int column, int row, unsigned char wal
 	painter.drawPixmap((column * 3 * m_unit) - m_unit, (row * 3 * m_unit) - m_unit, m_pixmap_corner[walls - 1]);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::drawWall(QPainter& painter, int column, int row, bool vertical) const
 {
@@ -226,7 +213,7 @@ void Theme::drawWall(QPainter& painter, int column, int row, bool vertical) cons
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Theme::cache(const QString& element, QPixmap& pixmap, const QRect& bounds, int angle) const
 {
@@ -245,4 +232,4 @@ void Theme::cache(const QString& element, QPixmap& pixmap, const QRect& bounds,
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
