@@ -1,28 +1,15 @@
-/***********************************************************************
- *
- * Copyright (C) 2007, 2008, 2009, 2012, 2014, 2015, 2016, 2017, 2018, 2019, 2020 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2007-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "window.h"
 
 #include "board.h"
 #include "locale_dialog.h"
 #include "new_game_dialog.h"
-#include "scores.h"
+#include "scores_dialog.h"
 #include "settings.h"
 
 #include <QAction>
@@ -41,7 +28,7 @@
 #include <QToolBar>
 #include <QWheelEvent>
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 static QIcon fetchIcon(const QString& name)
 {
@@ -53,19 +40,16 @@ static QIcon fetchIcon(const QString& name)
 	return QIcon::fromTheme(name, icon);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 Window::Window()
-:	m_pause_action(0)
+	: m_pause_action(nullptr)
 {
 	// Create game object
 	m_board = new Board(this);
 	setCentralWidget(m_board);
 	m_board->setFocus();
-
-	// Create scores window
-	m_scores = new Scores(this);
-	connect(m_board, &Board::finished, m_scores, &Scores::addScore);
+	connect(m_board, &Board::finished, this, &Window::gameFinished);
 
 	// Create actions
 	if (iconSize().width() == 26) {
@@ -87,7 +71,7 @@ Window::Window()
 	timer->start(300000);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Window::closeEvent(QCloseEvent* event)
 {
@@ -96,17 +80,7 @@ void Window::closeEvent(QCloseEvent* event)
 	QMainWindow::closeEvent(event);
 }
 
-// ============================================================================
-
-bool Window::event(QEvent* event)
-{
-	if ((event->type() == QEvent::WindowBlocked || event->type() == QEvent::WindowDeactivate) && m_pause_action && m_pause_action->isEnabled()) {
-		m_pause_action->setChecked(true);
-	}
-	return QMainWindow::event(event);
-}
-
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Window::wheelEvent(QWheelEvent* event)
 {
@@ -118,7 +92,7 @@ void Window::wheelEvent(QWheelEvent* event)
 	QMainWindow::wheelEvent(event);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Window::initActions()
 {
@@ -128,30 +102,30 @@ void Window::initActions()
 #endif
 
 	QMenu* game_menu = menuBar()->addMenu(tr("&Game"));
-	QAction* new_action = game_menu->addAction(fetchIcon("document-new"), tr("&New"), this, SLOT(newGame()), QKeySequence::New);
+	QAction* new_action = game_menu->addAction(fetchIcon("document-new"), tr("&New"), this, &Window::newGame, QKeySequence::New);
 	m_pause_action = game_menu->addAction(fetchIcon("media-playback-pause"), tr("&Pause"));
 	m_pause_action->setShortcut(tr("P"));
-	m_hint_action = game_menu->addAction(fetchIcon("games-hint"), tr("&Hint"), m_board, SLOT(hint()));
+	m_hint_action = game_menu->addAction(fetchIcon("games-hint"), tr("&Hint"), m_board, &Board::hint);
 	game_menu->addSeparator();
-	game_menu->addAction(fetchIcon("games-highscores"), tr("High &Scores"), m_scores, SLOT(exec()));
+	game_menu->addAction(fetchIcon("games-highscores"), tr("High &Scores"), this, &Window::showScores, tr("Ctrl+H"));
 	game_menu->addSeparator();
-	QAction* quit_action = game_menu->addAction(fetchIcon("application-exit"), tr("&Quit"), this, SLOT(close()), QKeySequence::Quit);
+	QAction* quit_action = game_menu->addAction(fetchIcon("application-exit"), tr("&Quit"), this, &Window::close, QKeySequence::Quit);
 	quit_action->setMenuRole(QAction::QuitRole);
 
 	QMenu* view_menu = menuBar()->addMenu(tr("View"));
-	QAction* zoom_in_action = view_menu->addAction(fetchIcon("zoom-in"), tr("Zoom &In"), m_board, SLOT(zoomIn()), tr("Ctrl++"));
+	QAction* zoom_in_action = view_menu->addAction(fetchIcon("zoom-in"), tr("Zoom &In"), m_board, &Board::zoomIn, tr("Ctrl++"));
 	connect(m_board, &Board::zoomInAvailable, zoom_in_action, &QAction::setEnabled);
-	QAction* zoom_out_action = view_menu->addAction(fetchIcon("zoom-out"), tr("Zoom &Out"), m_board, SLOT(zoomOut()), tr("Ctrl+-"));
+	QAction* zoom_out_action = view_menu->addAction(fetchIcon("zoom-out"), tr("Zoom &Out"), m_board, &Board::zoomOut, tr("Ctrl+-"));
 	connect(m_board, &Board::zoomOutAvailable, zoom_out_action, &QAction::setEnabled);
 
 	QMenu* settings_menu = menuBar()->addMenu(tr("&Settings"));
-	settings_menu->addAction(fetchIcon("preferences-desktop-locale"), tr("Application &Language..."), this, SLOT(setLocale()));
-	settings_menu->addAction(fetchIcon("games-config-options"), tr("&Preferences..."), this, SLOT(showSettings()));
+	settings_menu->addAction(fetchIcon("preferences-desktop-locale"), tr("Application &Language..."), this, &Window::setLocale);
+	settings_menu->addAction(fetchIcon("games-config-options"), tr("&Preferences..."), this, &Window::showSettings);
 
 	QMenu* help_menu = menuBar()->addMenu(tr("&Help"));
-	QAction* about_action = help_menu->addAction(fetchIcon("help-about"), tr("&About"), this, SLOT(about()));
+	QAction* about_action = help_menu->addAction(fetchIcon("help-about"), tr("&About"), this, &Window::about);
 	about_action->setMenuRole(QAction::AboutRole);
-	about_action = help_menu->addAction(QIcon(":/qt-project.org/qmessagebox/images/qtlogo-64.png"), tr("About &Qt"), qApp, SLOT(aboutQt()));
+	about_action = help_menu->addAction(QIcon(":/qt-project.org/qmessagebox/images/qtlogo-64.png"), tr("About &Qt"), qApp, &QApplication::aboutQt);
 	about_action->setMenuRole(QAction::AboutQtRole);
 
 	// Create toolbar
@@ -169,21 +143,21 @@ void Window::initActions()
 	setContextMenuPolicy(Qt::NoContextMenu);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Window::about()
 {
 	QMessageBox::about(this, tr("About"), QString("<p><center><big><b>%1 %2</b></big><br/>%3<br/><small>%4<br/>%5</small></center></p><p><center>%6<br/><small>%7</small></center></p>")
 		.arg(tr("CuteMaze"), QCoreApplication::applicationVersion(),
 			tr("A top-down maze game"),
-			tr("Copyright &copy; 2007-%1 Graeme Gott").arg("2020"),
+			tr("Copyright &copy; 2007-%1 Graeme Gott").arg("2021"),
 			tr("Released under the <a href=%1>GPL 3</a> license").arg("\"http://www.gnu.org/licenses/gpl.html\""),
 			tr("Icons are from the <a href=%1>Oxygen</a> theme").arg("\"http://www.oxygen-icons.org/\""),
 			tr("Used under the <a href=%1>LGPL 3</a> license").arg("\"http://www.gnu.org/licenses/lgpl.html\""))
 	);
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Window::newGame()
 {
@@ -193,7 +167,25 @@ void Window::newGame()
 	}
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
+
+void Window::gameFinished(int seconds, int steps, int algorithm, int size)
+{
+	ScoresDialog scores(this);
+	if (scores.addScore(seconds, steps, algorithm, size)) {
+		scores.exec();
+	}
+}
+
+//-----------------------------------------------------------------------------
+
+void Window::showScores()
+{
+	ScoresDialog scores(this);
+	scores.exec();
+}
+
+//-----------------------------------------------------------------------------
 
 void Window::showSettings()
 {
@@ -202,7 +194,7 @@ void Window::showSettings()
 	settings.exec();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
 
 void Window::setLocale()
 {
@@ -210,4 +202,4 @@ void Window::setLocale()
 	dialog.exec();
 }
 
-// ============================================================================
+//-----------------------------------------------------------------------------
