@@ -87,7 +87,7 @@
     </message>
     <message>
         <source>Please restart this application for the change in language to take effect.</source>
-        <translation>Herstart de applicatie om de taalwijziging toe te passen.</translation>
+        <translation>Herstart het programma om de taalwijziging toe te passen.</translation>
     </message>
 </context>
 <context>
@@ -146,50 +146,7 @@
     </message>
 </context>
 <context>
-    <name>QLabel</name>
-    <message>
-        <source>Hunt and Kill</source>
-        <translation>Jaag en vermoord</translation>
-    </message>
-    <message>
-        <source>Kruskal</source>
-        <translation>Kruskal</translation>
-    </message>
-    <message>
-        <source>Prim</source>
-        <translation>Prim</translation>
-    </message>
-    <message>
-        <source>Recursive Backtracker</source>
-        <translation>Recursieve routevinder</translation>
-    </message>
-    <message>
-        <source>Stack</source>
-        <translation>Opslagplaats </translation>
-    </message>
-    <message>
-        <source>Stack 2</source>
-        <translation>Opslagplaats 2</translation>
-    </message>
-    <message>
-        <source>Stack 3</source>
-        <translation>Opslagplaats 3</translation>
-    </message>
-    <message>
-        <source>Stack 4</source>
-        <translation>Opslagplaats 4</translation>
-    </message>
-    <message>
-        <source>Stack 5</source>
-        <translation>Opslagplaats 5</translation>
-    </message>
-</context>
-<context>
-    <name>Scores</name>
-    <message>
-        <source>CuteMaze Scores</source>
-        <translation>CuteMaze-scores</translation>
-    </message>
+    <name>ScoresDialog</name>
     <message>
         <source>Name</source>
         <translation>Naam</translation>
@@ -204,7 +161,7 @@
     </message>
     <message>
         <source>Steps</source>
-        <translation>Stappen</translation>
+        <translation>Aantal stappen</translation>
     </message>
     <message>
         <source>Algorithm</source>
@@ -219,10 +176,28 @@
         <translation>Gefeliciteerd!</translation>
     </message>
     <message>
-        <source>Your score has made the top ten.
-Please enter your name:</source>
-        <translation>Je score is goed genoeg voor de top 10.
-Voer je naam in:</translation>
+        <source>High Scores</source>
+        <translation>Topscores</translation>
+    </message>
+    <message>
+        <source>Rank</source>
+        <translation>Rang</translation>
+    </message>
+    <message>
+        <source>#%1</source>
+        <translation>#%1</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Je hebt je persoonlijk record verbroken!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Goed gedaan!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Je hebt een nieuwe topscore behaald!</translation>
     </message>
 </context>
 <context>
@@ -241,11 +216,11 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Show number of steps taken</source>
-        <translation>Laat het aantal stappen zien</translation>
+        <translation>Aantal stappen tonen</translation>
     </message>
     <message>
         <source>Show elapsed time</source>
-        <translation>Laat de verstreken tijd zien</translation>
+        <translation>Verstreken tijd tonen</translation>
     </message>
     <message>
         <source>Smooth movement</source>
@@ -273,7 +248,7 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Toggle Flag:</source>
-        <translation>Schakel flag:</translation>
+        <translation>Vlag tonen/verbergen:</translation>
     </message>
     <message>
         <source>Themes</source>
@@ -289,7 +264,7 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Select Theme File</source>
-        <translation>Selecteer themabestand</translation>
+        <translation>Kies een themabestand</translation>
     </message>
     <message>
         <source>Sorry</source>
@@ -297,7 +272,7 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Unable to create data folder.</source>
-        <translation>Het creëren van de gegevensmap is mislukt.</translation>
+        <translation>Het aanmaken van de gegevensmap is mislukt.</translation>
     </message>
     <message>
         <source>Unable to copy theme file.</source>
@@ -317,7 +292,7 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Show Hint:</source>
-        <translation>Hint weergeven:</translation>
+        <translation>Hint tonen:</translation>
     </message>
 </context>
 <context>
@@ -380,7 +355,7 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Zoom &amp;Out</source>
-        <translation>&amp;Uitzoomen</translation>
+        <translation>Uitz&amp;oomen</translation>
     </message>
     <message>
         <source>&amp;Settings</source>
@@ -388,11 +363,11 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>Application &amp;Language...</source>
-        <translation>Applicatietaa&amp;l...</translation>
+        <translation>Programmataa&amp;l...</translation>
     </message>
     <message>
         <source>&amp;Preferences...</source>
-        <translation>&amp;Voorkeuren...</translation>
+        <translation>&amp;Instellingen…</translation>
     </message>
     <message>
         <source>&amp;Help</source>
@@ -404,7 +379,7 @@ Voer je naam in:</translation>
     </message>
     <message>
         <source>A top-down maze game</source>
-        <translation>Een &apos;top-down&apos; doolhofspel</translation>
+        <translation>Een doolhofspel, van bovenaf gezien</translation>
     </message>
     <message>
         <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
@@ -422,5 +397,9 @@ Voer je naam in:</translation>
         <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
         <translation>Gebruikt onder de &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licentie</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
+    </message>
 </context>
 </TS>
